========
Sketcher
========

Sketcher commands are used to define the entities, such as the geometry, constraints, and dimensions, to create a sketch and to store the values and attributes associated with a particular sketch.


Create constrained sketches
---------------------------

.. autoclass:: abaqus.Sketcher.SketchModel.SketchModel
    :noindex:

    .. autoclasstoc::